@@ -1,2 +1,2 @@
 from streamtask.version import __version__
-__version__ = '0.4.0'
\ No newline at end of file
+from streamtask.streamtask import *
\ No newline at end of file
